@@ -196,31 +196,9 @@ macro_rules! __val {
     )
 }
 
+/// common view
 #[macro_export]
 macro_rules! val {
-    ($v:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}", stringify!($v), $v);
-    };
-    ($v:expr, $v2:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2,);
-    };
-    ($v:expr, $v2:expr, $v3:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3);
-    };
-    ($v:expr, $v2:expr, $v3:expr, $v4:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4);
-    };
-    ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5);
-    };
-    ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr, $v6:expr) => {
-        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
-    };
-}
-
-/// val line view
-#[macro_export]
-macro_rules! valn {
     ($v:expr) => {
         __val!("\n{}︎︎︎︎⏤►{:?}", stringify!($v), $v);
     };
@@ -241,9 +219,9 @@ macro_rules! valn {
     };
 }
 
-/// val vertical view
+/// val format
 #[macro_export]
-macro_rules! valv {
+macro_rules! valf {
     ($v:expr) => {
         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v);
     };
@@ -262,4 +240,27 @@ macro_rules! valv {
     ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr, $v6:expr) => {
         __val!("\n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?} \n⏤⏤ {}︎︎︎︎ ⏤⏤\n{:#?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
     };
-}
\ No newline at end of file
+}
+
+// in line
+#[macro_export]
+macro_rules! valn {
+    ($v:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}", stringify!($v), $v);
+    };
+    ($v:expr, $v2:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2,);
+    };
+    ($v:expr, $v2:expr, $v3:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3);
+    };
+    ($v:expr, $v2:expr, $v3:expr, $v4:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4);
+    };
+    ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5);
+    };
+    ($v:expr, $v2:expr, $v3:expr, $v4:expr, $v5:expr, $v6:expr) => {
+        __val!("{}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}, {}︎︎︎︎⏤►{:?}", stringify!($v), $v, stringify!($v2), $v2, stringify!($v3), $v3, stringify!($v4), $v4, stringify!($v5), $v5, stringify!($v6), $v6);
+    };
+}
